pub struct ConnectionEntry {
pub id: u64,
pub connection_type: i32,
pub config_data: String,
pub link_id: Option<String>,
pub direction: i32,
pub peer_node_id: Option<String>,
}Fields
id: u64connection_type: i32config_data: Stringlink_id: Option<String>direction: i32peer_node_id: Option<String>Remote peer’s node identifier (set after link negotiation).
Implementations
Sourceimpl ConnectionEntry
impl ConnectionEntry
Sourcepub fn connection_type(&self) -> ConnectionType
pub fn connection_type(&self) -> ConnectionType
Returns the enum value of connection_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_connection_type(&mut self, value: ConnectionType)
pub fn set_connection_type(&mut self, value: ConnectionType)
Sets connection_type to the provided enum value.
Sourcepub fn link_id(&self) -> &str
pub fn link_id(&self) -> &str
Returns the value of link_id, or the default value if link_id is unset.
Sourcepub fn direction(&self) -> ConnectionDirection
pub fn direction(&self) -> ConnectionDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: ConnectionDirection)
pub fn set_direction(&mut self, value: ConnectionDirection)
Sets direction to the provided enum value.
Sourcepub fn peer_node_id(&self) -> &str
pub fn peer_node_id(&self) -> &str
Returns the value of peer_node_id, or the default value if peer_node_id is unset.