pub struct RegisterNodeResponse {
pub original_message_id: String,
pub success: bool,
pub connections: Vec<Connection>,
pub routes: Vec<Route>,
}Fields
original_message_id: Stringsuccess: boolconnections: Vec<Connection>Current desired state for the node — connections to maintain and routes to set.
routes: Vec<Route>Trait Implementations
Sourceimpl Clone for RegisterNodeResponse
impl Clone for RegisterNodeResponse
Sourcefn clone(&self) -> RegisterNodeResponse
fn clone(&self) -> RegisterNodeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterNodeResponse
impl Debug for RegisterNodeResponse
Sourceimpl Default for RegisterNodeResponse
impl Default for RegisterNodeResponse
Sourcefn default() -> RegisterNodeResponse
fn default() -> RegisterNodeResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for RegisterNodeResponse
impl Message for RegisterNodeResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RegisterNodeResponse
impl PartialEq for RegisterNodeResponse
Sourcefn eq(&self, other: &RegisterNodeResponse) -> bool
fn eq(&self, other: &RegisterNodeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RegisterNodeResponse