pub struct Route {
pub name: Option<Name>,
pub link_id: Option<String>,
pub direction: Option<i32>,
}Fields
name: Option<Name>link_id: Option<String>direction: Option<i32>Implementations
Sourceimpl Route
impl Route
Sourcepub fn link_id(&self) -> &str
pub fn link_id(&self) -> &str
Returns the value of link_id, or the default value if link_id is unset.
Sourcepub fn direction(&self) -> ConnectionDirection
pub fn direction(&self) -> ConnectionDirection
Returns the enum value of direction, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: ConnectionDirection)
pub fn set_direction(&mut self, value: ConnectionDirection)
Sets direction to the provided enum value.