Config

Struct Config 

pub struct Config {
    pub servers: Vec<ServerConfig>,
    pub clients: Vec<ClientConfig>,
    pub token_provider: IdentityProviderConfig,
    pub token_verifier: IdentityVerifierConfig,
    pub recovery_ttl: Option<DurationString>,
}
Configuration for the Control-Plane / Data-Plane component

Fields

servers: Vec<ServerConfig>

Controller GRPC server settings

clients: Vec<ClientConfig>

Controller client config to connect to control plane

token_provider: IdentityProviderConfig

Token provider authentication configuration

token_verifier: IdentityVerifierConfig

Token verifier authentication configuration

recovery_ttl: Option<DurationString>

How long to keep routing state after a server-side connection drops, waiting for the peer to reconnect before notifying the control plane. Accepts duration strings like “30s”, “1s”, “500ms”. Defaults to 30 s.

Implementations

Source

impl Config

pub fn new() -> Self

Create a new Config instance with default values

pub fn is_default(&self) -> bool

pub fn with_servers(self, servers: Vec<ServerConfig>) -> Self

Create a new Config instance with the given servers

pub fn with_clients(self, clients: Vec<ClientConfig>) -> Self

Create a new Config instance with the given clients

pub fn with_token_provider_auth(self, auth: IdentityProviderConfig) -> Self

Set the token provider authentication configuration

pub fn with_token_verifier_auth(self, auth: IdentityVerifierConfig) -> Self

Set the token verifier authentication configuration

pub fn servers(&self) -> &[ServerConfig]

Get the list of server configurations

pub fn clients(&self) -> &[ClientConfig]

Get the list of client configurations

pub fn into_service( &self, id: ID, group_name: Option<String>, message_processor: Arc<MessageProcessor>, dataplane_servers: &[ServerConfig], ) -> ControlPlane

Create a ControlPlane service instance from this configuration